pub struct FieldInnerProduct;Expand description
An implementation of inner product over a dynamic field: projects the RHS entries into the field and folds with the field operations.
Field operations cannot overflow, so CHECK is ignored.